/*  Copyright (c) 1997, 1998 EarthStones. All rights reserved.

    Permission to use, copy, modify, and distribute this
    software and its documentation is governed by
    the Licensing Agreement included in the documentation.

    This source code is provided for illustration purposes
    only. Under the terms of the Licensing Agreement the
    licensed user may make one copy for back-up purposes
    but may not otherwise copy or distribute this source
    code.

    EarthStones makes no representations or warranties,
    either express or implied, including, but not limited to,
    implied warranties of merchantability and fitness for a
    particular purpose, with regard to the Software and the
    accompanying electronic documentation.
*/

package earthstones;

import java.awt.*;
import java.applet.*;
import java.net.*;
import java.util.*;

public class JDocViewer extends WebApplet {

    // Define applet's panels.
    // Note that the main panel
    // document is defined in WebApplet.

    Panel fore;                 // Applet's foreground panel
                                // creates colored outline in
                                // webpage.
    Panel banner;               // Applet's banner panel.
    ImagePanel logo, logoText;  // Elements of banner panel.
    DocFooter footer;           // Applet's footer panel.

    // Define variables used by document panel.

    protected String source = "";

    // The width and height of
    // the applet are set in the
    // applet tag. Their values should
    // be appropriate for the viewer's
    // screen resolution (i.e., already scaled).

	public void init() {
		super.init();
		// Sets color of WebApplet.background 
		// to create colored border around panel fore.
		background.setBackground(new Color(165, 70, 17));
    }

    // This method reads applet parameters and
    // shows (default) page as specified by them.

    public void load()  {
        
		fore = new Panel();
		fore.setBackground(Color.white);
        splash.setAppColor(fore.getBackground());
		fore.setLayout(null);
		fore.reshape(1, 1,
		                size().width - 2,
		                size().height - 2);

		background.add(fore);
        fore.add(document = new DocumentPanel(this));


	    // Create an instance of Web for this
	    // applet to manage access to user
	    // interface elements. Note that it is Web itself
	    // that is instantiated here, not a more
	    // specialized subclass such as JavaWeb.
	    // As a result, JDocViewer must manage its own
	    // updating by providing its own update()
	    // methods rather than relying on a Web
	    // subclass for this. Web instance is automatically
	    // registered with WebSite.

	    new Web(this);

		// Create banner panel

		banner = new Panel();
		banner.setLayout(null);
		fore.add(banner);
		banner.reshape(WebSite.web(this).scale(5),
		                WebSite.web(this).scale(5),
		                size().width - WebSite.web(this).scale(10) - 2,
		                WebSite.web(this).scale(28));
		banner.setBackground(Color.lightGray);
		// images scale automatically
		banner.add(logo = new ImagePanel(this, "images/EarthStones_Logo_Trnsp_Bkg.GIF",
		                                    24,
		                                    22));
		logo.move(3, 3);
		banner.add(logoText = new ImagePanel(this, "images/JDoc_Demo.GIF",
		                                        220,
		                                        22));
		logoText.move(32, 3);

		// Create footer panel

		fore.add(footer = new DocFooter(this, size().width - WebSite.web(this).scale(10) - 2));
        footer.move(WebSite.web(this).scale(5),
                    size().height - WebSite.web(this).scale(34) );

		// Size and register document panel.

        document.setHeight(size().height -
                           WebSite.web(this).scale(74));
        document.move(WebSite.web(this).scale(5),
                        WebSite.web(this).scale(37));
        WebSite.web(this).setDocument(document);

        // Read applet parameters

        loadDefaultPage((source = "contents"), true, false);
        
        postload();
    }

    public void update(String src, boolean scrl, boolean hscrl)    {
            Document theDocument = new Document(this, size().width - 12);
            theDocument.setSource(src);
            document.mode = theDocument.mode();
            theDocument.plainText = document.plainText;
            document.update(theDocument, scrl, hscrl);
            documentHasChanged();
    }

    // This method is called by DocumentPanel
    // to notify the its parent applet (i.e.,
    // this applet) that the current document has changed.

    public synchronized void documentHasChanged()    {
        String src;
        footer.Source.setText(src = document.currentState().source);
        if (src.equals("CGI_Results.htm") | 
                src.toUpperCase().endsWith("GIF") |
                src.toUpperCase().endsWith("JPG") |
                src.toUpperCase().endsWith("JPEG"))
            footer.Show.disable();
        else footer.Show.enable();
    }

}

// Define Applet's footer class.
// This (private) class is defined here since
// it is used only by JDocViewer.

class DocFooter extends Panel {

	// Define footer's components.

	TextField Source;       // Text box for displaying name
	                        // of document's source file.
	Button Show;            // Button toggles between rendering
	                        // HTML document and showing its
	                        // source code.
	Button Contents;        // Button returns to display of
	                        // table of contents file.

    // Define a few variables used by footer.

    private int width = 0;
    private WebApplet parentApp;

    DocFooter(WebApplet app, int wid)  {

        // note that the value passed for
        // wid is already scaled

        super();
        parentApp = app;
        width = wid;
        init();
    }

	public void init() {
        setLayout(null);

        // Scale and set background

		resize(width, WebSite.web(parentApp).scale(28));
		setFont(new Font("Helvetica", Font.PLAIN, 12));
		setBackground(Color.lightGray);

		// Add a text field for displaying
		// the source file's URL

		Source = new java.awt.TextField();
		Source.reshape(WebSite.web(parentApp).scale(84),
		                WebSite.web(parentApp).scale(2),
		                WebSite.web(parentApp).scale(298),
		                WebSite.web(parentApp).scale(25));
		Source.setEditable(false);
		Source.setFont(new Font(WebSite.web(parentApp).baseFont(),
		                Font.PLAIN,
		                WebSite.web(parentApp).captionFontSize()));
		add(Source);

		// Add a button to switch between
		// rendering a Document and showing
		// its HTML source code

		Show = new java.awt.Button("Show HTML");
		Show.reshape(WebSite.web(parentApp).scale(384),
		                WebSite.web(parentApp).scale(3),
		                WebSite.web(parentApp).scale(100),
		                WebSite.web(parentApp).scale(23));
		Show.setFont(new Font(WebSite.web(parentApp).baseFont(),
		                Font.PLAIN,
		                WebSite.web(parentApp).captionFontSize()));
		add(Show);

		// Add a button to switch back
		// to showing a table of contents

		Contents = new java.awt.Button("Contents");
		Contents.reshape(WebSite.web(parentApp).scale(3),
		                WebSite.web(parentApp).scale(3),
		                WebSite.web(parentApp).scale(80),
		                WebSite.web(parentApp).scale(23));
		Contents.setFont(new Font(WebSite.web(parentApp).baseFont(),
		                Font.PLAIN,
		                WebSite.web(parentApp).captionFontSize()));
		add(Contents);
		//}}
}

	public boolean handleEvent(Event event) {
	    
	    //WebApplet pApp = (WebApplet)WebSite.web(parentApp).getParentApp(Source);

        if (event.id != Event.ACTION_EVENT)
            return super.handleEvent(event);
            
        if ((event.target == Show) |
            (event.target == Source)) {

            // Handle Show button events

            if (Show.getLabel().equals("Show HTML"))  {

                // show HTML source
                parentApp.document.plainText = true;
                parentApp.update(Source.getText(), true, false);
                Show.setLabel("Show Doc");
            }
            else    {
                // render HTML code
                parentApp.document.plainText = false;
                parentApp.update(Source.getText(), true, false);
                Show.setLabel("Show HTML");
            }
        }
        if (event.target == Contents)   {

            // Handle Contents button events

            parentApp.document.plainText = false;
            String str;
            if (WebSite.web(parentApp).regStatus() == Web.NOT_LICENSED)     {
                parentApp.update("http://" + 
                                WebSite.site(parentApp).webServer + 
                                "/" + 
                                WebSite.web(parentApp).demoReg(), 
                                true, false);
                Show.setLabel("Show HTML");
            }
            else
                if (((str = parentApp.getParameter("contents")) != null) && (
                        str.length() > 0))  {
                    parentApp.update(str, true, false);
                    Show.setLabel("Show HTML");
                }
        }
		return super.handleEvent(event);
	}

}





