/*  Copyright (c) 1997, 1998 EarthStones. All rights reserved.

    Permission to use, copy, modify, and distribute this
    software and its documentation is governed by
    the Licensing Agreement included in the documentation.

    This source code is provided for illustration purposes
    only. Under the terms of the Licensing Agreement the
    licensed user may make one copy for back-up purposes
    but may not otherwise copy or distribute this source
    code.

    EarthStones makes no representations or warranties,
    either express or implied, including, but not limited to,
    implied warranties of merchantability and fitness for a
    particular purpose, with regard to the Software and the
    accompanying electronic documentation.
*/

package earthstones;

import java.awt.*;
import java.util.*;
import java.net.*;
import java.applet.*;

// This extension of Web provides specialized
// load and update methods for the all-Java
// implementation of WebSite (EarthStones Version 3).

public class JavaWeb extends Web {

    protected BannerPanel banner = null;    // The Web's banner panel.
    protected FooterPanel footer = null;    // The Web's footer panel.

    JavaWeb(Container apl)   {
        super(apl);
    }

    // Load method sets value of siteVersion
    // and loads default page.

    public synchronized void load()  {
        setSiteVersion(3.00f);
        WebSite.site(webApp).section(null).chapter(null).page(null).show();
    }

    // Update method updates all of
    // Web's user-interface components:
    // banner, graphic,document,
    // and footer.

    public synchronized void update()    {
        // Note: the wait cursor is set and reset
        // by each of the major UI panels.
        super.update();
        update(banner);
        updateGraphic();
        update(footer);
        update(document);
        // The value returned by graphicWidth()
        // is already scaled.
        document.move(scale(15 + 15) +
                            thePage.graphicWidth(),
                      document.location().y);
    }

    // This method is used when the footer's
    // "next image" button is clicked to update
    // only theImage variable and the graphic
    // panel.

    // Added in v1.03

    public synchronized void updateGraphic()  {
        if (!jumping)   {
            theImage = thePage.image();
            //graphic.update();
            update(graphic);
        }
        else jumping = false;
    }

    public void setBanner(BannerPanel bnr)  {
        banner = bnr;
    }

    public void setFooter(FooterPanel ftr)  {
        footer = ftr;
    }

    public BannerPanel banner() {
        return banner;
    }

    public FooterPanel footer() {
        return footer;
    }
}
