package earthstones;

import java.awt.*;
import java.applet.*;
import java.net.*;
import java.util.*;

// This extension of the Applet class reads
// certain essential parameters from the applet
// tag (e.g., platform and browser strings generated
// by javascript) necessary to get the applet
// up and running.

// It also manages the loading of a splash panel
// which transparently takes into account the fact
// that Internet Explorer and Navigator use different
// z-orders. The splash panel also provides status 
// information about optional registration checking
// for evaluations copies of the software.


// Finally, it creates and initializes an instance of Web
// (or one of its subclasses) to manage the user interface.
    
public class WebApplet extends Applet 
                            implements Runnable {
                                
    private boolean isFirstCall     // Indicates that this is
                     = true;        // the first call to
                                    // preload().

    Panel background;               // Panel which will hold all
                                    // of the applet's panels.
    DocumentPanel document;         // Applet's main panel.
    
    // Define variables used in connection with splash panel

    SplashPanel splash;             // Splash panel.
    Thread th;
    boolean loadSplash = true;
    boolean zFirstOnTop = true;     // Reflects how Java's z-order is 
                                    // implemented for the current browser 
                                    // and computing platorm. If true, the 
                                    // first component added to a container 
                                    // will appear on top of any overlapping 
                                    // components (this is the value for 
                                    // Sun's applet viewer as well as 
                                    // Internet Explorer on the Windows 
                                    // platform); if false, the last 
                                    // component added will appear on top 
                                    // (this case applies to Netscape 
                                    // Navigator and to Internet Explorer 
                                    // on the Macintosh).
                                    
   // Define variables used in connection with dialog panel                                 

    Panel dialog;                   // Displays dialog and 
                                    // on-Mouseover hints.

    WebApplet()  {
        super();
    }

	// Override in subclass.

	public void init()  {

	    // Subclass init() method
	    // should first size and
	    // position window and then call
	    //      super.init()
	    // to invoke this method.
	    // It can then perform any
	    // other initialization unique
	    // to the applet (e.g., setting
	    // the color of the background panel).

	    // Initialize the window

	    setLayout(null);
		addNotify();

	    // Set cursor to wait cursor.

	    getFrame().setCursor(Frame.WAIT_CURSOR);

	    // Read applet's loadSplash parameter
	    // and load splash panel if
	    // parameter has been set

	    String str;
	    if (((str = getParameter("loadSplash")) != null) &&
	            (str.length() > 0) &&
	            (str.toUpperCase().equals("FALSE")))
	        loadSplash = false;
	    zFirstOnTop = zFirstOnTop();

        // create splash panel to force
        // downloading SplashPanel class first.
        int mode = SplashPanel.SPLASH;
        if (getClass().getName().equals("earthstones.JSite"))
            mode = SplashPanel.LOGON;
        splash = new SplashPanel(this, false, mode);
        splash.hide();
        preload();
        add(dialog = new Panel());
        add(splash);
        preload();
	    if (loadSplash) {
	        // Splash panel no longer runs automatically.
	        // Need to invoke its run() method here
	        // using the custom startSplash() call.
	        splash.startSplash();
    	    splash.show();
	    }

	    // start() is called automatically when this method
	    // terminates.
}
	
	public void start() {
	    th = new Thread(this);
	    th.start();
	}

	// The new thread's start() method
	// calls th.run() which in turn
	// calls this.run().

	public void run()   {
	    load();
	}
	
	// Method is called twice and is responsible for
	// calling preloadThis() at the appropriate point
	// in the loading sequence, depending upon the
	// value of zFirstOnTop.
	
	public void preload()  {
	    if ((isFirstCall) &
                (!zFirstOnTop))    
            preloadThis();
	    if ((!isFirstCall) &
                (zFirstOnTop))    
            preloadThis();
        isFirstCall = false;
	}
	
	// This method loads the background
	// panel which holds the applets
	// other panels and will always appear
	// under the splash and dialog panels
	// regardless of z-order.
	
	public void preloadThis()   {
	    add(background = new Panel());
	    background.setLayout(null);
	    background.resize(size().width, size().height);
	}

    // May be overridden in subclass where load()
    // should have the following structure:
    //      
    //      [load the applet's panels
    //       into the background panel]
    //      [load the default page]
    //      [if a document is not loaded
    //       by default, execute the statements
    //       WebSite.web(this).killSplash = true;
    //       and
    //       getFrame().setCursor(Frame.DEFAULT_CURSOR);]
    //      postload();
    
    public void load()  {
        postload();
	}
	
	// This method loads the default page and returns
	// its file reference.
	
	public String loadDefaultPage(String pName, 
	                                boolean scroll,
	                                boolean hscroll)   {
	    String src = "";
        // Set the source variable depending upon
        // whether or not software has already been
        // registered.
        
        if (WebSite.web(this).regStatus() == Web.NOT_LICENSED)     {
            // Set source variable to that specified
            // by Web.demoReg on the website's server
            // Web.webServer.
            src = "http://" + 
                        WebSite.site(this).webServer + 
                        "/" + 
                        WebSite.web(this).demoReg();
        }
        else    {
            String str;
            // Set the source variable to that specified
            // by the value of the parameter named pName
            if (pName.length() > 0)
                if (((str = getParameter(pName)) != null) && (
                        str.length() > 0))
                    src = str;
        }
                
        // Load the specified default page (which will
        // then allow splash to be killed) or kill
        // splash panel now.

        if (src.length() > 0)
            update(src, scroll, hscroll);
        else    {
            WebSite.web(this).killSplash = true;
            getFrame().setCursor(Frame.DEFAULT_CURSOR);
        }
        
        // Return the name of the default page
        
        return src;
	}
    
	// This method should be invoked at the end
	// of subclass load() method to wait until
	// splash panel is ready to be killed.
	
	public void postload()  {
        dialog.setLayout(null);
	    dialog.hide();
        //WebSite.web(this).showDialog("This is a test.", 300);
        WebSite.web(this).waitToKillSplash(splash);
        splash.hide();
	}
	
	// These next two methods may be overridden 
	// in subclasses to update window contents

    public void update(String src, boolean scrl, boolean hscrl)    {
        // do whatever to update the window contents
        // and then notify this window.
        documentHasChanged();
    }
    
    // This method is called by DocumentPanel
    // to notify its parent applet (i.e.,
    // this applet) that the current document has changed.

    public synchronized void documentHasChanged()    {
        // do whatever to update UI context
        // (e.g., modify footer panel)
    }
    
	// Before destroying applet, remove
	// its Web and Site enteries in
	// WebSite's registries.

    public void destroy()   {
        WebSite.removeWeb(this);
        WebSite.removeSite(this);
        super.destroy();
    }

    // The remaining methods provide services
    // duplicated in the Web class but needed
    // here before the Web instance has been
    // created.

    protected boolean zFirstOnTop()    {
	    String str;
	    String browser = "";
	    String platform = "";
	    if (((str = getParameter("browser")) != null) &&
	            (str.length() > 0))
	        browser = str;
	    if (((str = getParameter("platform")) != null) &&
	            (str.length() > 0))
	        platform = str;
        if ((platform.indexOf("Mac") > -1) ||
                (browser.indexOf("NN") > -1))
            return zFirstOnTop = false;
        return true;
    }
    
   protected float resolutionFactor()    {
        Toolkit tk = getToolkit();
	    Dimension d = tk.getScreenSize();
        String str = String.valueOf(d.width) + "x" +
                            String.valueOf(d.height);
        int i = str.indexOf("x");
        str = str.substring(0, i);
        try {
            switch (Integer.parseInt(str))  {
                case 832:
                    break;
                case 800:
                    break;
                case 640:
                    break;
                default:
                    break;
            }
            float num = Float.valueOf(str).floatValue();
            if (num > 0) return num/1024.00f;
            else return 1.00f;
        }
        catch (NumberFormatException e) {}
        return 1.00f;
   }
   
	protected Frame getFrame() {
	    Object ret = this.getParent();
	    while (! (ret instanceof Frame))
	        ret = ((Component)ret).getParent();
	    return (Frame)ret;
	}
	
	//{{DECLARE_CONTROLS
	//}}
}
