package earthstones;

import java.awt.*;
import java.applet.*;
import java.net.*;
import java.util.*;

// This extension of the Frame class provides
// variables and methods for handling an
// application's command-line parameters which
// parallel the getParameter() method of an
// applet's and thus allows both applets and
// applications to share EarthStones' clas library.

// It also manages the loading of a splash panel
// which transparently takes into account the fact
// that Internet Explorer and Navigator use different
// z-orders.
    
// Finally, it creates and initializes an instance of Web
// (or one of its subclasses) to manage the user interface.
    
public class WebFrame extends Frame
                            implements Runnable  {

    private boolean isFirstCall     // Indicates that this is
                     = true;        // the first call to
                                    // preload().

    // Define variables which provide functionality
    // built into an applet but which must be defined
    // here so that both applications and applets
    // can share other class code.
    
    static URL documentBase = null;     // The base directory relative to
                                        // which paths will be set. Can
                                        // be set from the command line using
                                        // the syntax
                                        //      documentBase=aPath
    static Index params = new Index();  // Store the application's
                                        // command line arguments
                                        // name1=val1 name2=val2 ...
                                        // in this index of (name, val) pairs


    Panel background;                   // Panel which will hold all
                                        // of the applet's panels.
    DocumentPanel document;             // Applet's main panel.
    
    // Define variables used in connection with splash panel

    SplashPanel splash;                 // Splash panel.
    Thread th;
    boolean loadSplash = false;
    boolean zFirstOnTop = true;
    
   // Define variables used in connection with dialog panel                                 

    Panel dialog;                       // Displays dialog and 
                                        // on-Mouseover hints.

	public WebFrame()  {
			//{{INIT_CONTROLS
		setLayout(null);
		addNotify();
		resize(insets().left + insets().right + 430,insets().top + insets().bottom + 270);
		setTitle("Untitled");
		//}}
		//{{INIT_MENUS
		//}}
}

	public WebFrame(String title) {
	    this();
	    setTitle(title);
	}
	
	// Override this method in subclasses

	static public void main(String args[]) {
	    // set any default parameters here before
	    // reading command line parameters with
	    // a call to setParameters(). Use the
	    // syntax:
	    //      params.add("aName", "aValue")

	    setParameters(args);
	    (new WebFrame()).init();
	}
	
	// Override in subclass.
	
	public void init()  {
	    
	    // Subclass init() method
	    // should first size and
	    // position window and then call
	    //      super.init()
	    // to invoke this method.
	    // It can then perform any
	    // other initialization unique
	    // to the applet (e.g., setting
	    // the color of the background panel).
	    
	    // Show the window
	    
	    setLayout(null);
		addNotify();
	    show();
	    
	    // Set cursor to wait cursor.

	    getFrame().setCursor(Frame.WAIT_CURSOR);



	    // Read applet's loadSplash parameter
	    // and load splash panel if
	    // parameter has been set

	    String str;
	    if (((str = getParameter("loadSplash")) != null) &&
	            (str.length() > 0) &&
	            (str.toUpperCase().equals("FALSE")))
	        loadSplash = false;
	    zFirstOnTop = zFirstOnTop();
	    
        // create splash panel to force
        // downloading SplashPanel class first.
        splash = new SplashPanel(this, false);
        splash.hide();
        preload();
        add(dialog = new Panel());
        add(splash);
        preload();
	    if (loadSplash) {
	        // Splash panel no longer runs automatically.
	        // Need to invoke its run() method here
	        // using the custom startSplash() call.
	        splash.startSplash();
    	    splash.show();
	    }
	    
	    // Unlike an applet for which start() is called 
	    // automatically when its init() method
	    // terminates, here we must invoke it explicitly.
	    
	    start();
	}
	
    // The applet's start() method
    // is called automatically when
    // init() finishes execution.

	public void start() {
	    th = new Thread(this);
	    th.start();
	}

	// The new thread's start() method
	// calls th.run() which in turn
	// calls this.run().

	public void run()   {
	    load();
	}
	
	// Method is called twice and is responsible for
	// calling preloadThis() at the appropriate point
	// in the loading sequence, depending upon the
	// value of zFirstOnTop.
	
	public void preload()  {
	    if ((isFirstCall) &
                (!zFirstOnTop))    
            preloadThis();
	    if ((!isFirstCall) &
                (zFirstOnTop))    
            preloadThis();
        isFirstCall = false;
	}
	
	// This method loads the background
	// panel which holds the applets
	// other panels and will always appear
	// under the splash and dialog panels
	// regardless of z-order.
	
	public void preloadThis()   {
	    add(background = new Panel());
	    background.setLayout(null);
	    background.resize(size().width, size().height);
	}

    // May be overridden in subclass where load()
    // should have the following structure:
    //      
    //      [load the application's panels
    //       into the background panel]
    //      [load the default page]
    //      [if a document is not loaded
    //       by default, execute the statements
    //       WebSite.web(this).killSplash = true;
    //       and
    //       getFrame().setCursor(Frame.DEFAULT_CURSOR);]
    //      postload();
    
    public void load()  {
        postload();
	}
    
	
	// This method loads the default page and returns
	// its file reference.
	
	public String loadDefaultPage(String pName, 
	                                boolean scroll,
	                                boolean hscroll)   {
	    String src = "";
        // Set the source variable depending upon
        // whether or not software has already been
        // registered.
        
        if (WebSite.web(this).regStatus() == Web.NOT_LICENSED)     {
            // Set source variable to that specified
            // by Web.demoReg on the website's server
            // Web.webServer.
            src = "http://" + 
                        WebSite.site(this).webServer + 
                        "/" + 
                        WebSite.web(this).demoReg();
        }
        else    {
            String str;
            // Set the source variable to that specified
            // by the value of the parameter named pName
            if (pName.length() > 0)
                if (((str = getParameter(pName)) != null) && (
                        str.length() > 0))
                    src = str;
        }
                
        // Load the specified default page (which will
        // then allow splash to be killed) or kill
        // splash panel now.

        if (src.length() > 0)
            update(src, scroll, hscroll);
            
        else    {
            WebSite.web(this).killSplash = true;
            getFrame().setCursor(Frame.DEFAULT_CURSOR);
        }
        
        // Return the name of the default page
        
        return src;
	}
    
	// This method should be invoked at the end
	// of subclass load() method to wait until
	// splash panel is ready to be killed.
	
	public void postload()  {
	    
        // If this thread calls others,
        // you may need to move the statement
	    //      WebSite.web(this).killSplash = true;
	    // to prevent the spash screen from being
	    // killed prematurely.

        dialog.setLayout(null);
	    dialog.hide();
        WebSite.web(this).waitToKillSplash(splash);
        splash.hide();
	}
	
	// These next two methods must be overridden 
	// in subclasses to update window contents

    public void update(String src, boolean scrl, boolean hscrl)    {
        // do whatever to update the window contents
        // and then notify this window.
        documentHasChanged();
    }
    
    // This method is called by DocumentPanel
    // to notify the its parent applet (i.e.,
    // this applet) that the current document has changed.

    public synchronized void documentHasChanged()    {
        // do whatever to update UI context
        // (e.g., modify footer panel)
    }
    
    // Read the application's command line parameters
    // and set variables. 
    
	static public void setParameters(String args[])  {
	    for (int i=0; i<args.length; i++)   {
	        int idx = args[i].indexOf("=");
	        if (idx > -1)
	            params.add(args[i].substring(0, idx),
	                        args[i].substring(idx + 1));
            else
	            params.add(args[i], "");
	    }
	    URL url;
	    try     {
    	    if ((url = new URL("file:" + getParameter("baseDirectory"))) != null)
    	        documentBase = url;
    	}
    	catch (MalformedURLException e) {}
	}
	
	// These next four methods provide the 
	// application's counterparts to the applet's 
	// methods of the same names.

    public static String getParameter(String name)   {
        return (String)WebFrame.params.val(name);
    }
    
    public URL getDocumentBase() {
        return documentBase;
    }
    
    public void showDocument(URL url, String target)    {
        if (target.toUpperCase().equals("SELF") | 
                target.toUpperCase().equals("_SELF"))
            if (url.getFile().startsWith("ftp:") | 
                    url.getFile().startsWith("mailto:"))    
                WebSite.web(this).showDialog("The hyperlink you selected is attempting to access an ftp: or mailto: protocol which is not supported by this application.", 300);
            else
                update(url.getFile(), true, false);
        else    {
            WebSite.web(this).showDialog("The hyperlink you selected is attempting to open a resource in another window. Multiple program windows are not currently implemented.", 300);
        }
            
    }
    
	public Frame getFrame() {
        return this;
	}
	
	// These next three methods are used to
	// close the application.

	public boolean handleEvent(Event event) {
    	if (event.id == Event.WINDOW_DESTROY) {
            close();
            return true;
    	}
    	if (event.target instanceof Container)
        	if ((event.id == Event.MOUSE_DOWN) &
        	    (((Container)event.target).getParent() == dialog)) {
                dialog.hide();
                return true;
        	}
		return super.handleEvent(event);
	}

    public void close() {
        hide();         // hide the frame
        dispose();      // free the System resource
        System.exit(0); // close the application
    }
    
	// Before destroying applet, remove
	// its Web and Site enteries in
	// WebSite's registries.

    public void dispose()   {
        WebSite.removeWeb(this);
        WebSite.removeSite(this);
        super.dispose();
    }
    
    // The remaining methods provide services
    // duplicated in the Web class but needed
    // here before the Web instance has been
    // created.

    protected boolean zFirstOnTop()    {
	    String str;
	    String browser = "";
	    String platform = "";
	    if (((str = getParameter("browser")) != null) &&
	            (str.length() > 0))
	        browser = str;
	    if (((str = getParameter("platform")) != null) &&
	            (str.length() > 0))
	        platform = str;
        if ((platform.indexOf("Mac") > -1) ||
                (browser.indexOf("NN") > -1))
            return zFirstOnTop = false;
        return true;
    }
    
   protected float resolutionFactor()    {
        Toolkit tk = getToolkit();
	    Dimension d = tk.getScreenSize();
        String str = String.valueOf(d.width) + "x" +
                            String.valueOf(d.height);
        int i = str.indexOf("x");
        str = str.substring(0, i);
        try {
            switch (Integer.parseInt(str))  {
                case 832:
                    break;
                case 800:
                    break;
                case 640:
                    break;
                default:
                    break;
            }
            float num = Float.valueOf(str).floatValue();
            if (num > 0) return num/1024.00f;
            else return 1.00f;
        }
        catch (NumberFormatException e) {}
        return 1.00f;
   }
   
   public int scale(int num)   {
	    return (int)Math.round((double)((float)num*resolutionFactor()));
   }
   
	//{{DECLARE_CONTROLS
	//}}
	//{{DECLARE_MENUS
	//}}
}

